@@ -14,7 +14,6 @@
  * limitations under the License.
  *
 */
-#include <google/protobuf/text_format.h>
 
 #include <chrono>
 #include <csignal>
@@ -26,16 +25,16 @@
 #include <ignition/msgs.hh>
 
 #include "gtest/gtest.h"
-#include "gz/transport/AdvertiseOptions.hh"
-#include "gz/transport/MessageInfo.hh"
-#include "gz/transport/Node.hh"
-#include "gz/transport/NodeOptions.hh"
-#include "gz/transport/TopicStatistics.hh"
-#include "gz/transport/TopicUtils.hh"
-#include "gz/transport/TransportTypes.hh"
-#include "gz/transport/test_config.h"
+#include "ignition/transport/AdvertiseOptions.hh"
+#include "ignition/transport/MessageInfo.hh"
+#include "ignition/transport/Node.hh"
+#include "ignition/transport/NodeOptions.hh"
+#include "ignition/transport/TopicStatistics.hh"
+#include "ignition/transport/TopicUtils.hh"
+#include "ignition/transport/TransportTypes.hh"
+#include "ignition/transport/test_config.h"
 
-using namespace gz;
+using namespace ignition;
 
 static std::string partition; // NOLINT(*)
 static std::string g_FQNPartition; // NOLINT(*)
@@ -73,7 +72,7 @@ void reset()
 
 //////////////////////////////////////////////////
 /// \brief Function called each time a topic update is received.
-void cb(const msgs::Int32 &_msg)
+void cb(const ignition::msgs::Int32 &_msg)
 {
   EXPECT_EQ(_msg.data(), data);
   cbExecuted = true;
@@ -85,7 +84,7 @@ void cb(const msgs::Int32 &_msg)
 
 //////////////////////////////////////////////////
 /// \brief Function called each time a topic update is received.
-void cb2(const msgs::Int32 &_msg)
+void cb2(const ignition::msgs::Int32 &_msg)
 {
   EXPECT_EQ(_msg.data(), data);
   cb2Executed = true;
@@ -94,8 +93,8 @@ void cb2(const msgs::Int32 &_msg)
 //////////////////////////////////////////////////
 /// \brief Function called each time a topic update is received.
 /// This callback includes message information.
-void cbInfo(const msgs::Int32 &_msg,
-            const transport::MessageInfo &_info)
+void cbInfo(const ignition::msgs::Int32 &_msg,
+            const ignition::transport::MessageInfo &_info)
 {
   EXPECT_EQ(_info.Topic(), g_topic);
   EXPECT_EQ(_msg.data(), data);
@@ -108,14 +107,14 @@ void cbInfo(const msgs::Int32 &_msg,
 
 //////////////////////////////////////////////////
 void rawCbInfo(const char *_msgData, const size_t _size,
-               const transport::MessageInfo &_info)
+               const ignition::transport::MessageInfo &_info)
 {
   EXPECT_EQ(_info.Topic(), g_topic);
   EXPECT_EQ(g_FQNPartition, _info.Partition());
   EXPECT_TRUE(_info.IntraProcess());
   cbExecuted = true;
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   EXPECT_TRUE(msg.ParseFromArray(_msgData, _size));
   EXPECT_EQ(msg.data(), data);
 
@@ -126,16 +125,15 @@ void rawCbInfo(const char *_msgData, const size_t _size,
 /// \brief A generic callback.
 void genericCb(const transport::ProtoMsg &_msg)
 {
-  std::string content;
-  ASSERT_TRUE(google::protobuf::TextFormat::PrintToString(_msg, &content));
+  std::string content = _msg.DebugString();
   EXPECT_TRUE(content.find(std::to_string(data)) != std::string::npos);
   genericCbExecuted = true;
 }
 
 //////////////////////////////////////////////////
 /// \brief Provide a service call.
-bool srvEcho(const msgs::Int32 &_req,
-  msgs::Int32 &_rep)
+bool srvEcho(const ignition::msgs::Int32 &_req,
+  ignition::msgs::Int32 &_rep)
 {
   srvExecuted = true;
 
@@ -146,7 +144,7 @@ bool srvEcho(const msgs::Int32 &_req,
 
 //////////////////////////////////////////////////
 /// \brief Provide a service call without input.
-bool srvWithoutInput(msgs::Int32 &_rep)
+bool srvWithoutInput(ignition::msgs::Int32 &_rep)
 {
   srvExecuted = true;
   _rep.set_data(data);
@@ -155,7 +153,7 @@ bool srvWithoutInput(msgs::Int32 &_rep)
 
 //////////////////////////////////////////////////
 /// \brief Provide a service call without waiting for response.
-void srvWithoutOutput(const msgs::Int32 &_req)
+void srvWithoutOutput(const ignition::msgs::Int32 &_req)
 {
   srvExecuted = true;
 
@@ -165,7 +163,7 @@ void srvWithoutOutput(const msgs::Int32 &_req)
 
 //////////////////////////////////////////////////
 /// \brief Service call response callback.
-void response(const msgs::Int32 &_rep, const bool _result)
+void response(const ignition::msgs::Int32 &_rep, const bool _result)
 {
   EXPECT_EQ(_rep.data(), data);
   EXPECT_TRUE(_result);
@@ -176,14 +174,14 @@ void response(const msgs::Int32 &_rep, const bool _result)
 
 //////////////////////////////////////////////////
 /// \brief Service call response callback.
-void wrongResponse(const msgs::Vector3d &/*_rep*/, bool /*_result*/)
+void wrongResponse(const ignition::msgs::Vector3d &/*_rep*/, bool /*_result*/)
 {
   wrongResponseExecuted = true;
 }
 
 //////////////////////////////////////////////////
 /// \brief Callback for receiving Vector3d data.
-void cbVector(const msgs::Vector3d &/*_msg*/)
+void cbVector(const ignition::msgs::Vector3d &/*_msg*/)
 {
   cbVectorExecuted = true;
 }
@@ -222,8 +220,8 @@ class MyTestClass
 
   /// \brief Member function used as a callback for responding to a service
   /// call.
-  public: bool Echo(const msgs::Int32 &_req,
-    msgs::Int32 &_rep)
+  public: bool Echo(const ignition::msgs::Int32 &_req,
+    ignition::msgs::Int32 &_rep)
   {
     EXPECT_EQ(_req.data(), data);
     _rep.set_data(_req.data());
@@ -233,7 +231,7 @@ class MyTestClass
 
   /// \brief Member function used as a callback for responding to a service
   /// call without input.
-  public: bool WithoutInput(msgs::Int32 &_rep)
+  public: bool WithoutInput(ignition::msgs::Int32 &_rep)
   {
     _rep.set_data(data);
     this->callbackSrvExecuted = true;
@@ -242,14 +240,14 @@ class MyTestClass
 
   // Member function used as a callback for responding to a service call
   // without without waiting for a response.
-  public: void WithoutOutput(const msgs::Int32 &_req)
+  public: void WithoutOutput(const ignition::msgs::Int32 &_req)
   {
     EXPECT_EQ(_req.data(), data);
     this->callbackSrvExecuted = true;
   }
 
   /// \brief Response callback to a service request.
-  public: void EchoResponse(const msgs::Int32 &_rep,
+  public: void EchoResponse(const ignition::msgs::Int32 &_rep,
     const bool _result)
   {
     EXPECT_EQ(_rep.data(), data);
@@ -259,7 +257,7 @@ class MyTestClass
   }
 
   /// \brief Response callback to a service request without input.
-  public: void WithoutInputResponse(const msgs::Int32 &_rep,
+  public: void WithoutInputResponse(const ignition::msgs::Int32 &_rep,
     const bool _result)
   {
     EXPECT_EQ(_rep.data(), data);
@@ -269,7 +267,7 @@ class MyTestClass
   }
 
   /// \brief Member function called each time a topic update is received.
-  public: void Cb(const msgs::Int32 &_msg)
+  public: void Cb(const ignition::msgs::Int32 &_msg)
   {
     EXPECT_EQ(_msg.data(), data);
     this->callbackExecuted = true;
@@ -277,8 +275,8 @@ class MyTestClass
 
   /// \brief Member function called each time a topic update is received.
   /// This callback accepts a parameter with some message information.
-  public: void CbInfo(const msgs::Int32 &_msg,
-                      const transport::MessageInfo &_info)
+  public: void CbInfo(const ignition::msgs::Int32 &_msg,
+                      const ignition::transport::MessageInfo &_info)
   {
     EXPECT_EQ(_info.Topic(), g_topic);
     EXPECT_EQ(_msg.data(), data);
@@ -291,19 +289,19 @@ class MyTestClass
   /// \brief Advertise a topic and publish a message.
   public: void SendSomeData()
   {
-    msgs::Int32 msg;
+    ignition::msgs::Int32 msg;
     msg.set_data(data);
 
     // Advertise an illegal topic.
-    auto pub = this->node.Advertise<msgs::Int32>("invalid topic");
+    auto pub = this->node.Advertise<ignition::msgs::Int32>("invalid topic");
     EXPECT_FALSE(pub);
     EXPECT_FALSE(pub.HasConnections());
 
-    auto pubId = this->node.Advertise<msgs::Int32>("invalid topic");
+    auto pubId = this->node.Advertise<ignition::msgs::Int32>("invalid topic");
     EXPECT_FALSE(pubId);
     EXPECT_FALSE(pubId.Valid());
 
-    pubId = this->node.Advertise<msgs::Int32>(g_topic);
+    pubId = this->node.Advertise<ignition::msgs::Int32>(g_topic);
     EXPECT_TRUE(pubId);
     EXPECT_TRUE(pubId.Valid());
     EXPECT_TRUE(pubId.HasConnections());
@@ -314,10 +312,10 @@ class MyTestClass
   /// blocking call.
   public: void TestServiceCall()
   {
-    msgs::Int32 req;
-    msgs::Int32 rep;
-    msgs::Vector3d wrongReq;
-    msgs::Vector3d wrongRep;
+    ignition::msgs::Int32 req;
+    ignition::msgs::Int32 rep;
+    ignition::msgs::Vector3d wrongReq;
+    ignition::msgs::Vector3d wrongRep;
     int timeout = 500;
     bool result;
 
@@ -343,19 +341,6 @@ class MyTestClass
 
     this->Reset();
 
-    // Request a valid service using RequestRaw.
-    std::string reqStr, repStr, repTypeName;
-    req.SerializeToString(&reqStr);
-    EXPECT_TRUE(this->node.RequestRaw(g_topic, reqStr,
-          std::string(req.GetTypeName()),
-          std::string(rep.GetTypeName()), timeout, repStr, result));
-    rep.ParseFromString(repStr);
-    ASSERT_TRUE(result);
-    EXPECT_EQ(rep.data(), data);
-    EXPECT_TRUE(this->callbackSrvExecuted);
-
-    this->Reset();
-
     // Service requests with wrong types.
     EXPECT_FALSE(this->node.Request(g_topic, wrongReq, timeout, rep, result));
     EXPECT_FALSE(this->node.Request(g_topic, req, timeout, wrongRep, result));
@@ -369,8 +354,8 @@ class MyTestClass
   /// using non-blocking and blocking call.
   public: void TestServiceCallWithoutInput()
   {
-    msgs::Int32 rep;
-    msgs::Vector3d wrongRep;
+    ignition::msgs::Int32 rep;
+    ignition::msgs::Vector3d wrongRep;
     int timeout = 500;
     bool result;
 
@@ -406,8 +391,8 @@ class MyTestClass
   /// \brief Advertise and request a service without waiting for response.
   public: void TestServiceCallWithoutOutput()
   {
-    msgs::Int32 req;
-    msgs::Vector3d wrongReq;
+    ignition::msgs::Int32 req;
+    ignition::msgs::Vector3d wrongReq;
 
     req.set_data(data);
 
@@ -475,11 +460,11 @@ void CreatePubSubTwoThreads(
   transport::AdvertiseMessageOptions opts;
   opts.SetScope(_sc);
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node(_nodeOptions);
-  auto pub = node.Advertise<msgs::Int32>(g_topic, opts);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic, opts);
   EXPECT_TRUE(pub);
 
   // Subscribe to a topic in a different thread and wait until the callback is
@@ -511,9 +496,9 @@ TEST(NodePubTest, BoolOperatorTest)
   const transport::Node::Publisher pub_const;
   EXPECT_FALSE(pub);
   EXPECT_FALSE(pub_const);
-  pub = node.Advertise<msgs::Vector3d>(g_topic);
+  pub = node.Advertise<ignition::msgs::Vector3d>(g_topic);
   const transport::Node::Publisher pub2_const =
-      node2.Advertise<msgs::Vector3d>(g_topic);
+      node2.Advertise<ignition::msgs::Vector3d>(g_topic);
   EXPECT_TRUE(pub);
   EXPECT_TRUE(pub2_const);
 }
@@ -524,7 +509,7 @@ TEST(NodeTest, PubWithoutAdvertise)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   // Check that an invalid namespace is ignored. The callbacks are expecting an
@@ -542,14 +527,14 @@ TEST(NodeTest, PubWithoutAdvertise)
   EXPECT_TRUE(node1.SubscribedTopics().empty());
   EXPECT_TRUE(node1.AdvertisedServices().empty());
 
-  auto pub1 = node1.Advertise(g_topic, std::string(msg.GetTypeName()));
+  auto pub1 = node1.Advertise(g_topic, msg.GetTypeName());
   EXPECT_TRUE(pub1);
 
   auto advertisedTopics = node1.AdvertisedTopics();
   ASSERT_EQ(advertisedTopics.size(), 1u);
   EXPECT_EQ(advertisedTopics.at(0), g_topic);
 
-  auto pub2 = node2.Advertise<msgs::Int32>(g_topic);
+  auto pub2 = node2.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub2);
   advertisedTopics = node2.AdvertisedTopics();
   ASSERT_EQ(advertisedTopics.size(), 1u);
@@ -586,15 +571,15 @@ TEST(NodeTest, PubSubSameThread)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
 
   // Advertise an illegal topic.
-  EXPECT_FALSE(node.Advertise<msgs::Int32>("invalid topic"));
+  EXPECT_FALSE(node.Advertise<ignition::msgs::Int32>("invalid topic"));
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   // Subscribe to an illegal topic.
@@ -634,12 +619,12 @@ TEST(NodeTest, PubSubSameThreadGenericCb)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.Subscribe(g_topic, genericCb));
@@ -678,11 +663,11 @@ TEST(NodeTest, PubSubSameThreadMessageInfo)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.Subscribe(g_topic, cbInfo));
@@ -718,11 +703,11 @@ TEST(NodeTest, RawPubSubSameThreadMessageInfo)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.Subscribe(g_topic, cbInfo));
@@ -731,8 +716,7 @@ TEST(NodeTest, RawPubSubSameThreadMessageInfo)
   std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
   // Publish a first message.
-  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(),
-        std::string(msg.GetTypeName())));
+  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(), msg.GetTypeName()));
 
   // Give some time to the subscribers.
   std::this_thread::sleep_for(std::chrono::milliseconds(100));
@@ -743,8 +727,7 @@ TEST(NodeTest, RawPubSubSameThreadMessageInfo)
   reset();
 
   // Publish a second message on topic.
-  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(),
-        std::string(msg.GetTypeName())));
+  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(), msg.GetTypeName()));
 
   // Give some time to the subscribers.
   std::this_thread::sleep_for(std::chrono::milliseconds(100));
@@ -760,11 +743,11 @@ TEST(NodeTest, RawPubRawSubSameThreadMessageInfo)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.SubscribeRaw(g_topic, rawCbInfo));
@@ -773,8 +756,7 @@ TEST(NodeTest, RawPubRawSubSameThreadMessageInfo)
   std::this_thread::sleep_for(std::chrono::milliseconds(100));
 
   // Publish a first message.
-  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(),
-        std::string(msg.GetTypeName())));
+  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(), msg.GetTypeName()));
 
   // Give some time to the subscribers.
   std::this_thread::sleep_for(std::chrono::milliseconds(100));
@@ -785,8 +767,7 @@ TEST(NodeTest, RawPubRawSubSameThreadMessageInfo)
   reset();
 
   // Publish a second message on topic.
-  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(),
-        std::string(msg.GetTypeName())));
+  EXPECT_TRUE(pub.PublishRaw(msg.SerializeAsString(), msg.GetTypeName()));
 
   // Give some time to the subscribers.
   std::this_thread::sleep_for(std::chrono::milliseconds(100));
@@ -802,11 +783,11 @@ TEST(NodeTest, PubRawSubSameThreadMessageInfo)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.SubscribeRaw(g_topic, rawCbInfo));
@@ -843,20 +824,20 @@ TEST(NodeTest, PubSubSameThreadLambda)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   std::mutex mutex;
   std::condition_variable condition;
 
   bool executed = false;
-  std::function<void(const msgs::Int32&)> subCb =
-    [&executed, &mutex, &condition](const msgs::Int32 &_msg)
+  std::function<void(const ignition::msgs::Int32&)> subCb =
+    [&executed, &mutex, &condition](const ignition::msgs::Int32 &_msg)
   {
     EXPECT_EQ(_msg.data(), data);
     std::lock_guard<std::mutex> lk(mutex);
@@ -890,19 +871,19 @@ TEST(NodeTest, PubSubSameThreadLambdaMessageInfo)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   bool executed = false;
-  std::function<void(const msgs::Int32&,
-                     const transport::MessageInfo &)> subCb =
-    [&executed](const msgs::Int32 &_msg,
-                const transport::MessageInfo &_info)
+  std::function<void(const ignition::msgs::Int32&,
+                     const ignition::transport::MessageInfo &)> subCb =
+    [&executed](const ignition::msgs::Int32 &_msg,
+                const ignition::transport::MessageInfo &_info)
   {
     EXPECT_EQ(_info.Topic(), g_topic);
     EXPECT_EQ(_msg.data(), data);
@@ -937,11 +918,11 @@ TEST(NodeTest, AdvertiseTwoEqualTopics)
   transport::Node node1;
   transport::Node node2;
 
-  auto pub1 = node1.Advertise<msgs::Int32>(g_topic);
+  auto pub1 = node1.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub1);
-  auto pub2 = node1.Advertise<msgs::StringMsg>(g_topic);
+  auto pub2 = node1.Advertise<ignition::msgs::StringMsg>(g_topic);
   EXPECT_FALSE(pub2);
-  auto pub3 = node2.Advertise<msgs::StringMsg>(g_topic);
+  auto pub3 = node2.Advertise<ignition::msgs::StringMsg>(g_topic);
   EXPECT_TRUE(pub3);
 }
 
@@ -1033,14 +1014,14 @@ TEST(NodeTest, PubSubOneThreadTwoSubs)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node1;
   transport::Node node2;
 
   {
-    auto pub1 = node1.Advertise<msgs::Int32>(g_topic);
+    auto pub1 = node1.Advertise<ignition::msgs::Int32>(g_topic);
     EXPECT_TRUE(pub1);
 
     // Subscribe to topic in node1.
@@ -1162,8 +1143,8 @@ TEST(NodeTest, TypeMismatch)
 {
   reset();
 
-  msgs::Int32 rightMsg;
-  msgs::Vector3d wrongMsg;
+  ignition::msgs::Int32 rightMsg;
+  ignition::msgs::Vector3d wrongMsg;
   rightMsg.set_data(1);
   wrongMsg.set_x(1);
   wrongMsg.set_y(2);
@@ -1171,7 +1152,7 @@ TEST(NodeTest, TypeMismatch)
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_FALSE(pub.Publish(wrongMsg));
@@ -1186,7 +1167,7 @@ TEST(NodeTest, ServiceCallAsync)
 {
   reset();
 
-  msgs::Int32 req;
+  ignition::msgs::Int32 req;
   req.set_data(data);
 
   transport::Node node;
@@ -1313,7 +1294,7 @@ TEST(NodeTest, ServiceWithoutOutputCallAsync)
   reset();
 
   transport::Node node;
-  msgs::Int32 req;
+  ignition::msgs::Int32 req;
   req.set_data(data);
 
   // Advertise an invalid service name.
@@ -1355,8 +1336,8 @@ TEST(NodeTest, ServiceCallAsyncLambda)
 {
   reset();
 
-  std::function<bool(const msgs::Int32 &, msgs::Int32 &)>
-    advCb = [](const msgs::Int32 &_req, msgs::Int32 &_rep)
+  std::function<bool(const ignition::msgs::Int32 &, ignition::msgs::Int32 &)>
+    advCb = [](const ignition::msgs::Int32 &_req, ignition::msgs::Int32 &_rep)
     -> bool
   {
     EXPECT_EQ(_req.data(), data);
@@ -1365,19 +1346,19 @@ TEST(NodeTest, ServiceCallAsyncLambda)
   };
 
   transport::Node node;
-  EXPECT_TRUE((node.Advertise<msgs::Int32,
-        msgs::Int32>(g_topic, advCb)));
+  EXPECT_TRUE((node.Advertise<ignition::msgs::Int32,
+        ignition::msgs::Int32>(g_topic, advCb)));
 
   bool executed = false;
-  std::function<void(const msgs::Int32 &, const bool)> reqCb =
-    [&executed](const msgs::Int32 &_rep, const bool _result)
+  std::function<void(const ignition::msgs::Int32 &, const bool)> reqCb =
+    [&executed](const ignition::msgs::Int32 &_rep, const bool _result)
   {
     EXPECT_EQ(_rep.data(), data);
     EXPECT_TRUE(_result);
     executed = true;
   };
 
-  msgs::Int32 req;
+  ignition::msgs::Int32 req;
   req.set_data(data);
 
   EXPECT_TRUE((node.Request(g_topic, req, reqCb)));
@@ -1393,19 +1374,19 @@ TEST(NodeTest, ServiceCallWithoutInputAsyncLambda)
 {
   reset();
 
-  std::function<bool(msgs::Int32 &)> advCb =
-    [](msgs::Int32 &_rep) -> bool
+  std::function<bool(ignition::msgs::Int32 &)> advCb =
+    [](ignition::msgs::Int32 &_rep) -> bool
   {
     _rep.set_data(data);
     return true;
   };
 
   transport::Node node;
-  EXPECT_TRUE((node.Advertise<msgs::Int32>(g_topic, advCb)));
+  EXPECT_TRUE((node.Advertise<ignition::msgs::Int32>(g_topic, advCb)));
 
   bool executed = false;
-  std::function<void(const msgs::Int32 &, const bool)> reqCb =
-    [&executed](const msgs::Int32 &_rep, const bool _result)
+  std::function<void(const ignition::msgs::Int32 &, const bool)> reqCb =
+    [&executed](const ignition::msgs::Int32 &_rep, const bool _result)
   {
     EXPECT_EQ(_rep.data(), data);
     EXPECT_TRUE(_result);
@@ -1426,17 +1407,17 @@ TEST(NodeTest, ServiceCallWithoutOutputAsyncLambda)
 {
   bool executed = false;
 
-  std::function<void(const msgs::Int32 &)> advCb =
-    [&executed](const msgs::Int32 &_req)
+  std::function<void(const ignition::msgs::Int32 &)> advCb =
+    [&executed](const ignition::msgs::Int32 &_req)
   {
     EXPECT_EQ(_req.data(), data);
     executed = true;
   };
 
   transport::Node node;
-  EXPECT_TRUE((node.Advertise<msgs::Int32>(g_topic, advCb)));
+  EXPECT_TRUE((node.Advertise<ignition::msgs::Int32>(g_topic, advCb)));
 
-  msgs::Int32 req;
+  ignition::msgs::Int32 req;
   req.set_data(data);
 
   EXPECT_TRUE(node.Request(g_topic, req));
@@ -1449,7 +1430,7 @@ TEST(NodeTest, MultipleServiceCallAsync)
 {
   reset();
 
-  msgs::Int32 req;
+  ignition::msgs::Int32 req;
   req.set_data(data);
 
   transport::Node node;
@@ -1567,7 +1548,7 @@ TEST(NodeTest, MultipleServiceWithoutOutputCallAsync)
   reset();
 
   transport::Node node;
-  msgs::Int32 req;
+  ignition::msgs::Int32 req;
   req.set_data(data);
 
   // Advertise an invalid service name.
@@ -1620,8 +1601,8 @@ TEST(NodeTest, ServiceCallSync)
 {
   reset();
 
-  msgs::Int32 req;
-  msgs::Int32 rep;
+  ignition::msgs::Int32 req;
+  ignition::msgs::Int32 rep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -1648,7 +1629,7 @@ TEST(NodeTest, ServiceCallWithoutInputSync)
 {
   reset();
 
-  msgs::Int32 rep;
+  ignition::msgs::Int32 rep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -1673,8 +1654,8 @@ TEST(NodeTest, ServiceCallSyncTimeout)
 {
   reset();
 
-  msgs::Int32 req;
-  msgs::Int32 rep;
+  ignition::msgs::Int32 req;
+  ignition::msgs::Int32 rep;
   bool result;
   int64_t timeout = 1000;
 
@@ -1706,7 +1687,7 @@ TEST(NodeTest, ServiceCallWithoutInputSyncTimeout)
 {
   reset();
 
-  msgs::Int32 rep;
+  ignition::msgs::Int32 rep;
   bool result;
   int64_t timeout = 1000;
 
@@ -1739,11 +1720,11 @@ void createInfinitePublisher()
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   auto i = 0;
@@ -1820,16 +1801,16 @@ TEST(NodeTest, PubSubWrongTypesOnPublish)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
-  msgs::Vector3d msgV;
+  ignition::msgs::Vector3d msgV;
   msgV.set_x(1);
   msgV.set_y(2);
   msgV.set_z(3);
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.Subscribe(g_topic, cb));
@@ -1864,14 +1845,14 @@ TEST(NodeTest, PubSubWrongTypesOnSubscription)
 {
   reset();
 
-  msgs::Vector3d msgV;
+  ignition::msgs::Vector3d msgV;
   msgV.set_x(1);
   msgV.set_y(2);
   msgV.set_z(3);
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Vector3d>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Vector3d>(g_topic);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.Subscribe(g_topic, cb));
@@ -1896,13 +1877,13 @@ TEST(NodeTest, PubSubWrongTypesTwoSubscribers)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node1;
   transport::Node node2;
 
-  auto pub1 = node1.Advertise<msgs::Int32>(g_topic);
+  auto pub1 = node1.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub1);
 
   // Good subscriber.
@@ -1935,15 +1916,15 @@ TEST(NodeTest, SubThrottled)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
   EXPECT_TRUE(pub);
 
-  transport::SubscribeOptions opts;
+  ignition::transport::SubscribeOptions opts;
   opts.SetMsgsPerSec(1u);
   EXPECT_TRUE(node.Subscribe(g_topic, cb, opts));
 
@@ -1970,14 +1951,14 @@ TEST(NodeTest, PubThrottled)
 {
   reset();
 
-  msgs::Int32 msg;
+  ignition::msgs::Int32 msg;
   msg.set_data(data);
 
   transport::Node node;
 
-  transport::AdvertiseMessageOptions opts;
+  ignition::transport::AdvertiseMessageOptions opts;
   opts.SetMsgsPerSec(1u);
-  auto pub = node.Advertise<msgs::Int32>(g_topic, opts);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic, opts);
   EXPECT_TRUE(pub);
 
   EXPECT_TRUE(node.Subscribe(g_topic, cb));
@@ -2008,8 +1989,8 @@ TEST(NodeTest, SrvRequestWrongReq)
 {
   reset();
 
-  msgs::Vector3d wrongReq;
-  msgs::Int32 rep;
+  ignition::msgs::Vector3d wrongReq;
+  ignition::msgs::Int32 rep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -2039,8 +2020,8 @@ TEST(NodeTest, SrvRequestWrongRep)
 {
   reset();
 
-  msgs::Int32 req;
-  msgs::Vector3d wrongRep;
+  ignition::msgs::Int32 req;
+  ignition::msgs::Vector3d wrongRep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -2068,7 +2049,7 @@ TEST(NodeTest, SrvWithoutInputRequestWrongRep)
 {
   reset();
 
-  msgs::Vector3d wrongRep;
+  ignition::msgs::Vector3d wrongRep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -2095,9 +2076,9 @@ TEST(NodeTest, SrvTwoRequestsOneWrong)
 {
   reset();
 
-  msgs::Int32 req;
-  msgs::Int32 goodRep;
-  msgs::Vector3d badRep;
+  ignition::msgs::Int32 req;
+  ignition::msgs::Int32 goodRep;
+  ignition::msgs::Vector3d badRep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -2130,8 +2111,8 @@ TEST(NodeTest, SrvWithoutInputTwoRequestsOneWrong)
 {
   reset();
 
-  msgs::Int32 goodRep;
-  msgs::Vector3d badRep;
+  ignition::msgs::Int32 goodRep;
+  ignition::msgs::Vector3d badRep;
   bool result;
   unsigned int timeout = 1000;
 
@@ -2162,8 +2143,8 @@ TEST(NodeTest, TopicList)
   transport::Node node1;
   transport::Node node2;
 
-  auto pub1 = node1.Advertise<msgs::Int32>("topic1");
-  auto pub2 = node2.Advertise<msgs::Int32>("topic2");
+  auto pub1 = node1.Advertise<ignition::msgs::Int32>("topic1");
+  auto pub2 = node2.Advertise<ignition::msgs::Int32>("topic2");
 
   node1.TopicList(topics);
   EXPECT_EQ(topics.size(), 2u);
@@ -2193,7 +2174,7 @@ TEST(NodeTest, TopicListRemap)
   nodeOptions.AddTopicRemap(g_topic, g_topic_remap);
   transport::Node node(nodeOptions);
 
-  auto pub = node.Advertise<msgs::Int32>(g_topic);
+  auto pub = node.Advertise<ignition::msgs::Int32>(g_topic);
 
   node.TopicList(topics);
   ASSERT_EQ(1u, topics.size());
@@ -2266,14 +2247,14 @@ TEST(NodeTest, WrongTopicRemap)
 /// \brief Check the high water mark of the receiving message buffer.
 TEST(NodeTest, RcvHwm)
 {
-  EXPECT_EQ(transport::kDefaultRcvHwm, transport::rcvHwm());
+  EXPECT_EQ(ignition::transport::kDefaultRcvHwm, ignition::transport::rcvHwm());
 }
 
 //////////////////////////////////////////////////
 /// \brief Check the high water mark of the sending message buffer.
 TEST(NodeTest, SndHwm)
 {
-  EXPECT_EQ(transport::kDefaultSndHwm, transport::sndHwm());
+  EXPECT_EQ(ignition::transport::kDefaultSndHwm, ignition::transport::sndHwm());
 }
 
 //////////////////////////////////////////////////
@@ -2284,7 +2265,7 @@ TEST(NodePubTest, DestructionOrder)
 
   {
     transport::Node node;
-    pub = node.Advertise<msgs::Vector3d>(g_topic);
+    pub = node.Advertise<ignition::msgs::Vector3d>(g_topic);
   }
 }
 
@@ -2294,7 +2275,7 @@ TEST(NodePubTest, DestructionOrder)
 /// and is able to terminate.
 TEST(NodeTest, waitForShutdownSIGINT)
 {
-  std::thread aThread([]{transport::waitForShutdown();});
+  std::thread aThread([]{ignition::transport::waitForShutdown();});
   std::this_thread::sleep_for(std::chrono::milliseconds(50));
   raise(SIGINT);
   aThread.join();
@@ -2306,7 +2287,7 @@ TEST(NodeTest, waitForShutdownSIGINT)
 /// and is able to terminate.
 TEST(NodeTest, waitForShutdownSIGTERM)
 {
-  std::thread aThread([]{transport::waitForShutdown();});
+  std::thread aThread([]{ignition::transport::waitForShutdown();});
   std::this_thread::sleep_for(std::chrono::milliseconds(50));
   raise(SIGTERM);
   aThread.join();
